# coding: utf-8

# flake8: noqa

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "CambAI",
    "AudioSeparationApi",
    "DictionariesApi",
    "DubApi",
    "StoriesApi",
    "TextToAudioApi",
    "TextToSpeechApi",
    "TextToVoiceApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AudioOutputFileURLResponse",
    "AudioOutputType",
    "AudioSeparationRunInfoResponse",
    "BodyTranslateTranslatePost",
    "CreateAPIKeyRequestPayload",
    "CreateCustomVoiceOut",
    "CreateTTSRequestPayload",
    "CreateTTSStreamRequestPayload",
    "CreateTextToAudioRequestPayload",
    "CreateTextToVoiceRequestPayload",
    "CreateTranslatedStoryRequestPayload",
    "CreateTranslatedTTSRequestPayload",
    "CreateTranslationStreamRequestPayload",
    "DialogueItem",
    "Dictionary",
    "DubAltFormatResponseBody",
    "DubbedOutputInAltFormatRequestPayload",
    "EndToEndDubbingRequestPayload",
    "ExpireAPIKeyRequestPayload",
    "Formalities",
    "Gender",
    "HTTPValidationError",
    "LanguageItem",
    "Languages",
    "OrchestratorPipelineResult",
    "OutputAPIKey",
    "OutputFormat",
    "OutputType",
    "RequestDubbedOutputInAltFormat200Response",
    "RunInfoResponse",
    "StoryRunInfoResponse",
    "TTSStreamOutputFormat",
    "TaskID",
    "TaskStatus",
    "TextToVoiceRunInfoResponse",
    "TranscriptDataType",
    "TranscriptFileFormat",
    "TranslationResult",
    "ValidationError",
    "ValidationErrorLocInner",
    "VideoOutputTypeWithoutAVI",
    "VoiceItem",
]

# import apis into sdk package
from cambai.api.apis_api import CambAI as CambAI
from cambai.api.audio_separation_api import AudioSeparationApi as AudioSeparationApi
from cambai.api.dictionaries_api import DictionariesApi as DictionariesApi
from cambai.api.dub_api import DubApi as DubApi
from cambai.api.stories_api import StoriesApi as StoriesApi
from cambai.api.text_to_audio_api import TextToAudioApi as TextToAudioApi
from cambai.api.text_to_speech_api import TextToSpeechApi as TextToSpeechApi
from cambai.api.text_to_voice_api import TextToVoiceApi as TextToVoiceApi

# import ApiClient
from cambai.api_response import ApiResponse as ApiResponse
from cambai.api_client import ApiClient as ApiClient
from cambai.configuration import Configuration as Configuration
from cambai.exceptions import OpenApiException as OpenApiException
from cambai.exceptions import ApiTypeError as ApiTypeError
from cambai.exceptions import ApiValueError as ApiValueError
from cambai.exceptions import ApiKeyError as ApiKeyError
from cambai.exceptions import ApiAttributeError as ApiAttributeError
from cambai.exceptions import ApiException as ApiException

# import models into sdk package
from cambai.models.audio_output_file_url_response import AudioOutputFileURLResponse as AudioOutputFileURLResponse
from cambai.models.audio_output_type import AudioOutputType as AudioOutputType
from cambai.models.audio_separation_run_info_response import AudioSeparationRunInfoResponse as AudioSeparationRunInfoResponse
from cambai.models.body_translate_translate_post import BodyTranslateTranslatePost as BodyTranslateTranslatePost
from cambai.models.create_api_key_request_payload import CreateAPIKeyRequestPayload as CreateAPIKeyRequestPayload
from cambai.models.create_custom_voice_out import CreateCustomVoiceOut as CreateCustomVoiceOut
from cambai.models.create_tts_request_payload import CreateTTSRequestPayload as CreateTTSRequestPayload
# from cambai.models.create_tts_stream_request_payload import CreateTTSStreamRequestPayload as CreateTTSStreamRequestPayload
from cambai.models.create_text_to_audio_request_payload import CreateTextToAudioRequestPayload as CreateTextToAudioRequestPayload
from cambai.models.create_text_to_voice_request_payload import CreateTextToVoiceRequestPayload as CreateTextToVoiceRequestPayload
from cambai.models.create_translated_story_request_payload import CreateTranslatedStoryRequestPayload as CreateTranslatedStoryRequestPayload
from cambai.models.create_translated_tts_request_payload import CreateTranslatedTTSRequestPayload as CreateTranslatedTTSRequestPayload
from cambai.models.create_translation_stream_request_payload import CreateTranslationStreamRequestPayload as CreateTranslationStreamRequestPayload
from cambai.models.dialogue_item import DialogueItem as DialogueItem
from cambai.models.dictionary import Dictionary as Dictionary
from cambai.models.dub_alt_format_response_body import DubAltFormatResponseBody as DubAltFormatResponseBody
from cambai.models.dubbed_output_in_alt_format_request_payload import DubbedOutputInAltFormatRequestPayload as DubbedOutputInAltFormatRequestPayload
from cambai.models.end_to_end_dubbing_request_payload import EndToEndDubbingRequestPayload as EndToEndDubbingRequestPayload
from cambai.models.expire_api_key_request_payload import ExpireAPIKeyRequestPayload as ExpireAPIKeyRequestPayload
from cambai.models.formalities import Formalities as Formalities
from cambai.models.gender import Gender as Gender
from cambai.models.http_validation_error import HTTPValidationError as HTTPValidationError
from cambai.models.language_item import LanguageItem as LanguageItem
from cambai.models.languages import Languages as Languages
from cambai.models.orchestrator_pipeline_result import OrchestratorPipelineResult as OrchestratorPipelineResult
from cambai.models.output_api_key import OutputAPIKey as OutputAPIKey
from cambai.models.output_format import OutputFormat as OutputFormat
from cambai.models.output_type import OutputType as OutputType
from cambai.models.request_dubbed_output_in_alt_format200_response import RequestDubbedOutputInAltFormat200Response as RequestDubbedOutputInAltFormat200Response
from cambai.models.run_info_response import RunInfoResponse as RunInfoResponse
from cambai.models.story_run_info_response import StoryRunInfoResponse as StoryRunInfoResponse
from cambai.models.tts_stream_output_format import TTSStreamOutputFormat as TTSStreamOutputFormat
from cambai.models.task_id import TaskID as TaskID
from cambai.models.task_status import TaskStatus as TaskStatus
from cambai.models.text_to_voice_run_info_response import TextToVoiceRunInfoResponse as TextToVoiceRunInfoResponse
from cambai.models.transcript_data_type import TranscriptDataType as TranscriptDataType
from cambai.models.transcript_file_format import TranscriptFileFormat as TranscriptFileFormat
from cambai.models.translation_result import TranslationResult as TranslationResult
from cambai.models.validation_error import ValidationError as ValidationError
from cambai.models.validation_error_loc_inner import ValidationErrorLocInner as ValidationErrorLocInner
from cambai.models.video_output_type_without_avi import VideoOutputTypeWithoutAVI as VideoOutputTypeWithoutAVI
from cambai.models.voice_item import VoiceItem as VoiceItem



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Languages(int, Enum):
    """
    Languages
    """

    """
    allowed enum values
    """
    NUMBER_1 = 1
    NUMBER_2 = 2
    NUMBER_3 = 3
    NUMBER_4 = 4
    NUMBER_5 = 5
    NUMBER_6 = 6
    NUMBER_7 = 7
    NUMBER_8 = 8
    NUMBER_9 = 9
    NUMBER_10 = 10
    NUMBER_11 = 11
    NUMBER_12 = 12
    NUMBER_13 = 13
    NUMBER_14 = 14
    NUMBER_15 = 15
    NUMBER_16 = 16
    NUMBER_17 = 17
    NUMBER_18 = 18
    NUMBER_19 = 19
    NUMBER_20 = 20
    NUMBER_21 = 21
    NUMBER_22 = 22
    NUMBER_23 = 23
    NUMBER_24 = 24
    NUMBER_25 = 25
    NUMBER_26 = 26
    NUMBER_27 = 27
    NUMBER_28 = 28
    NUMBER_29 = 29
    NUMBER_30 = 30
    NUMBER_31 = 31
    NUMBER_32 = 32
    NUMBER_33 = 33
    NUMBER_34 = 34
    NUMBER_35 = 35
    NUMBER_36 = 36
    NUMBER_37 = 37
    NUMBER_38 = 38
    NUMBER_39 = 39
    NUMBER_40 = 40
    NUMBER_41 = 41
    NUMBER_42 = 42
    NUMBER_43 = 43
    NUMBER_44 = 44
    NUMBER_45 = 45
    NUMBER_46 = 46
    NUMBER_47 = 47
    NUMBER_48 = 48
    NUMBER_49 = 49
    NUMBER_50 = 50
    NUMBER_51 = 51
    NUMBER_52 = 52
    NUMBER_53 = 53
    NUMBER_54 = 54
    NUMBER_55 = 55
    NUMBER_56 = 56
    NUMBER_57 = 57
    NUMBER_58 = 58
    NUMBER_59 = 59
    NUMBER_60 = 60
    NUMBER_61 = 61
    NUMBER_62 = 62
    NUMBER_63 = 63
    NUMBER_64 = 64
    NUMBER_65 = 65
    NUMBER_66 = 66
    NUMBER_67 = 67
    NUMBER_68 = 68
    NUMBER_69 = 69
    NUMBER_70 = 70
    NUMBER_71 = 71
    NUMBER_72 = 72
    NUMBER_73 = 73
    NUMBER_74 = 74
    NUMBER_75 = 75
    NUMBER_76 = 76
    NUMBER_77 = 77
    NUMBER_78 = 78
    NUMBER_79 = 79
    NUMBER_80 = 80
    NUMBER_81 = 81
    NUMBER_82 = 82
    NUMBER_83 = 83
    NUMBER_84 = 84
    NUMBER_85 = 85
    NUMBER_86 = 86
    NUMBER_87 = 87
    NUMBER_88 = 88
    NUMBER_89 = 89
    NUMBER_90 = 90
    NUMBER_91 = 91
    NUMBER_92 = 92
    NUMBER_93 = 93
    NUMBER_94 = 94
    NUMBER_95 = 95
    NUMBER_96 = 96
    NUMBER_97 = 97
    NUMBER_98 = 98
    NUMBER_99 = 99
    NUMBER_100 = 100
    NUMBER_101 = 101
    NUMBER_102 = 102
    NUMBER_103 = 103
    NUMBER_104 = 104
    NUMBER_105 = 105
    NUMBER_106 = 106
    NUMBER_107 = 107
    NUMBER_108 = 108
    NUMBER_109 = 109
    NUMBER_110 = 110
    NUMBER_111 = 111
    NUMBER_112 = 112
    NUMBER_113 = 113
    NUMBER_114 = 114
    NUMBER_115 = 115
    NUMBER_116 = 116
    NUMBER_117 = 117
    NUMBER_118 = 118
    NUMBER_119 = 119
    NUMBER_120 = 120
    NUMBER_121 = 121
    NUMBER_122 = 122
    NUMBER_123 = 123
    NUMBER_124 = 124
    NUMBER_125 = 125
    NUMBER_126 = 126
    NUMBER_127 = 127
    NUMBER_128 = 128
    NUMBER_129 = 129
    NUMBER_130 = 130
    NUMBER_131 = 131
    NUMBER_132 = 132
    NUMBER_133 = 133
    NUMBER_134 = 134
    NUMBER_135 = 135
    NUMBER_136 = 136
    NUMBER_137 = 137
    NUMBER_138 = 138
    NUMBER_139 = 139
    NUMBER_140 = 140
    NUMBER_141 = 141
    NUMBER_142 = 142
    NUMBER_143 = 143
    NUMBER_144 = 144
    NUMBER_145 = 145
    NUMBER_146 = 146
    NUMBER_147 = 147
    NUMBER_148 = 148

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Languages from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import os
import unittest

from cambai.api.apis_api import CambAI


class TestApisApi(unittest.TestCase):
    """ApisApi unit test stubs"""

    def setUp(self) -> None:
        api_key = "CAMB_API_KEY"
        self.api = CambAI(api_key=api_key)

    def tearDown(self) -> None:
        pass

    def test_create_audio_separation(self) -> None:
        """Test case for create_audio_separation

        Create Audio Separation
        """
        pass

    def test_create_custom_voice(self) -> None:
        """Test case for create_custom_voice

        Create Custom Voice
        """
        pass

    def test_create_end_to_end_dubbing(self) -> None:
        """Test case for create_end_to_end_dubbing

        End To End Dubbing
        """
        pass

    def test_create_story(self) -> None:
        """Test case for create_story

        Create Story
        """
        pass

    def test_create_text_to_sound(self) -> None:
        """Test case for create_text_to_sound

        Create Text to Sound
        """
        pass

    def test_create_transcription(self) -> None:
        """Test case for create_transcription

        Create Transcription
        """
        pass

    def test_create_translated_story(self) -> None:
        """Test case for create_translated_story

        Create Translated Story
        """
        pass

    def test_create_translated_tts(self) -> None:
        """Test case for create_translated_tts

        Create Translated Tts
        """
        pass

    def test_create_translation(self) -> None:
        """Test case for create_translation

        Create Translation
        """
        pass

    def test_create_translation_stream(self) -> None:
        """Test case for create_translation_stream

        Create Translation Stream
        """
        pass

    def test_create_tts(self) -> None:
        """Test case for create_tts

        Create Tts
        """
        pass

    # def test_create_tts_stream(self) -> None:
    #     """Test case for create_tts_stream

    #     Create TTS Stream
    #     """
    #     pass

    def test_create_voice_from_description(self) -> None:
        """Test case for create_voice_from_description

        Create Voice from Description
        """
        pass

    def test_dictionaries_get(self) -> None:
        """Test case for dictionaries_get

        Get Workspace Dictionaries
        """
        pass

    def test_get_audio_separation_run_info_by_id(self) -> None:
        """Test case for get_audio_separation_run_info_by_id

        Get Audio Separation Run Info
        """
        pass

    def test_get_audio_separation_status_by_id(self) -> None:
        """Test case for get_audio_separation_status_by_id

        Get Audio Separation Status
        """
        pass

    def test_get_dubbed_run_info_by_id(self) -> None:
        """Test case for get_dubbed_run_info_by_id

        Get Dubbed Run Info
        """
        pass

    def test_get_end_to_end_dubbing_status_by_id(self) -> None:
        """Test case for get_end_to_end_dubbing_status_by_id

        Get End To End Dubbing Status
        """
        pass

    def test_get_source_languages(self) -> None:
        """Test case for get_source_languages

        Get Source Languages
        """
        pass

    def test_get_story_run_info_by_id(self) -> None:
        """Test case for get_story_run_info_by_id

        Get Story Run Info
        """
        pass

    def test_get_story_status_by_id(self) -> None:
        """Test case for get_story_status_by_id

        Get Story Status
        """
        pass

    def test_get_target_languages(self) -> None:
        """Test case for get_target_languages

        Get Target Languages
        """
        pass

    def test_get_text_to_audio_status_by_id(self) -> None:
        """Test case for get_text_to_audio_status_by_id

        Get Text To Audio Status
        """
        pass

    def test_get_text_to_sound_run_result_by_id(self) -> None:
        """Test case for get_text_to_sound_run_result_by_id

        Get Text to Sound Run Result
        """
        pass

    def test_get_text_to_voice_run_result_by_id(self) -> None:
        """Test case for get_text_to_voice_run_result_by_id

        Get Text-to-Voice Run Result
        """
        pass

    def test_get_transcription_result_by_id(self) -> None:
        """Test case for get_transcription_result_by_id

        Get Transcription Result
        """
        pass

    def test_get_transcription_task_status_by_id(self) -> None:
        """Test case for get_transcription_task_status_by_id

        Create Transcription Task Status
        """
        pass

    def test_get_translated_story_run_info(self) -> None:
        """Test case for get_translated_story_run_info

        Get Translated Story Run Info
        """
        pass

    def test_get_translated_story_status_by_id(self) -> None:
        """Test case for get_translated_story_status_by_id

        Get Translated Story Status
        """
        pass

    def test_get_translated_tts_task_status_by_id(self) -> None:
        """Test case for get_translated_tts_task_status_by_id

        Create Translated Tts Task Status
        """
        pass

    def test_get_translation_result_by_id(self) -> None:
        """Test case for get_translation_result_by_id

        Get Translation Result
        """
        pass

    def test_get_translation_task_status_by_id(self) -> None:
        """Test case for get_translation_task_status_by_id

        Create translation Task Status
        """
        pass

    def test_get_tts_result_by_id(self) -> None:
        """Test case for get_tts_result_by_id

        Get Tts Result
        """
        pass

    def test_get_tts_run_info_by_id(self) -> None:
        """Test case for get_tts_run_info_by_id

        Get Tts Run Info
        """
        pass

    def test_list_voices(self) -> None:
        """Test case for list_voices

        List Voices
        """
        pass

    def test_text_to_voice_task_id_get(self) -> None:
        """Test case for text_to_voice_task_id_get

        Get Text-to-Voice Task Status
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cambai.models.languages import Languages
from typing import Optional, Set
from typing_extensions import Self

class VoiceItem(BaseModel):
    """
    VoiceItem
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="A unique identifier for the voice record. Each voice is assigned a distinct `id` for reference")
    voice_name: Optional[StrictStr] = Field(default=None, description="The name or label assigned to the voice.")
    gender: Optional[StrictInt] = Field(default=None, description="Represents the gender of the voice. Values are encoded as integers.")
    age: Optional[StrictInt] = Field(default=None, description="The age of the voice represented as an integer. If the age is unknown or not applicable, the value is `null`.")
    description: Optional[StrictStr] = Field(default=None, description="A brief summary of the custom voice—e.g. its intended use, tone or character traits.")
    transcript: Optional[StrictStr] = Field(default=None, description="The transcribed text of the voice recording, if available.")
    is_published: Optional[StrictBool] = Field(default=None, description="Specifies whether the voice is shared on the marketplace or not.")
    language: Optional[Languages] = Field(default=None, description="The language specified when creating the custom voice.")
    __properties: ClassVar[List[str]] = ["id", "voice_name", "gender", "age", "description", "transcript", "is_published", "language"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VoiceItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VoiceItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "voice_name": obj.get("voice_name"),
            "gender": obj.get("gender"),
            "age": obj.get("age"),
            "description": obj.get("description"),
            "transcript": obj.get("transcript"),
            "is_published": obj.get("is_published"),
            "language": obj.get("language")
        })
        return _obj





# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TTSStreamOutputFormat(str, Enum):
    """
    TTSStreamOutputFormat
    """

    """
    allowed enum values
    """
    WAV = 'wav'
    FLAC = 'flac'
    ADTS = 'adts'
    PCM_S16LE = 'pcm_s16le'
    PCM_S32LE = 'pcm_s32le'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TTSStreamOutputFormat from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class CreateTextToVoiceRequestPayload(BaseModel):
    """
    CreateTextToVoiceRequestPayload
    """ # noqa: E501
    text: StrictStr = Field(description="The text content that will be converted into synthesized speech.")
    voice_description: StrictStr = Field(description="A detailed description of the desired voice characteristics to guide the synthesis engine. You can specify attributes such as gender, age, accent, emotional tone, speaking style, or cultural context to create authentic voices.")
    __properties: ClassVar[List[str]] = ["text", "voice_description"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateTextToVoiceRequestPayload from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateTextToVoiceRequestPayload from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "text": obj.get("text"),
            "voice_description": obj.get("voice_description")
        })
        return _obj





# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictBytes, StrictInt, StrictStr
from typing import List, Optional, Tuple, Union
from typing_extensions import Annotated
from cambai.models.create_translated_story_request_payload import CreateTranslatedStoryRequestPayload
from cambai.models.languages import Languages
from cambai.models.orchestrator_pipeline_result import OrchestratorPipelineResult
from cambai.models.story_run_info_response import StoryRunInfoResponse
from cambai.models.task_id import TaskID

from cambai.api_client import ApiClient, RequestSerialized
from cambai.api_response import ApiResponse
from cambai.rest import RESTResponseType


class StoriesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_story(
        self,
        file: Annotated[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]], Field(description="The text file (`.txt`) or Word document (`.docx`) that its contents will be used for creating a story.")],
        source_language: Annotated[Languages, Field(description="The language of the contents in the input file.")],
        title: Annotated[Optional[StrictStr], Field(description="The title of the story.")] = None,
        description: Annotated[Optional[StrictStr], Field(description="A brief description of the story.")] = None,
        narrator_voice_id: Annotated[Optional[StrictInt], Field(description="Specifies the identifier of the AI voice that will narrate the story. This voice selection determines the tone, accent, and delivery style used to bring the contents of the uploaded .txt or .docx file to life.")] = None,
        chosen_dictionaries: Annotated[Optional[Annotated[List[StrictInt], Field(min_length=1)]], Field(description="An optional list of dictionary IDs selected by the user. Each entry must be an integer corresponding to a valid dictionary ID. If provided, at least one ID is required.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TaskID:
        """Create Story


        :param file: The text file (`.txt`) or Word document (`.docx`) that its contents will be used for creating a story. (required)
        :type file: bytearray
        :param source_language: The language of the contents in the input file. (required)
        :type source_language: Languages
        :param title: The title of the story.
        :type title: str
        :param description: A brief description of the story.
        :type description: str
        :param narrator_voice_id: Specifies the identifier of the AI voice that will narrate the story. This voice selection determines the tone, accent, and delivery style used to bring the contents of the uploaded .txt or .docx file to life.
        :type narrator_voice_id: int
        :param chosen_dictionaries: An optional list of dictionary IDs selected by the user. Each entry must be an integer corresponding to a valid dictionary ID. If provided, at least one ID is required.
        :type chosen_dictionaries: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_story_serialize(
            file=file,
            source_language=source_language,
            title=title,
            description=description,
            narrator_voice_id=narrator_voice_id,
            chosen_dictionaries=chosen_dictionaries,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TaskID",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_story_with_http_info(
        self,
        file: Annotated[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]], Field(description="The text file (`.txt`) or Word document (`.docx`) that its contents will be used for creating a story.")],
        source_language: Annotated[Languages, Field(description="The language of the contents in the input file.")],
        title: Annotated[Optional[StrictStr], Field(description="The title of the story.")] = None,
        description: Annotated[Optional[StrictStr], Field(description="A brief description of the story.")] = None,
        narrator_voice_id: Annotated[Optional[StrictInt], Field(description="Specifies the identifier of the AI voice that will narrate the story. This voice selection determines the tone, accent, and delivery style used to bring the contents of the uploaded .txt or .docx file to life.")] = None,
        chosen_dictionaries: Annotated[Optional[Annotated[List[StrictInt], Field(min_length=1)]], Field(description="An optional list of dictionary IDs selected by the user. Each entry must be an integer corresponding to a valid dictionary ID. If provided, at least one ID is required.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TaskID]:
        """Create Story


        :param file: The text file (`.txt`) or Word document (`.docx`) that its contents will be used for creating a story. (required)
        :type file: bytearray
        :param source_language: The language of the contents in the input file. (required)
        :type source_language: Languages
        :param title: The title of the story.
        :type title: str
        :param description: A brief description of the story.
        :type description: str
        :param narrator_voice_id: Specifies the identifier of the AI voice that will narrate the story. This voice selection determines the tone, accent, and delivery style used to bring the contents of the uploaded .txt or .docx file to life.
        :type narrator_voice_id: int
        :param chosen_dictionaries: An optional list of dictionary IDs selected by the user. Each entry must be an integer corresponding to a valid dictionary ID. If provided, at least one ID is required.
        :type chosen_dictionaries: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_story_serialize(
            file=file,
            source_language=source_language,
            title=title,
            description=description,
            narrator_voice_id=narrator_voice_id,
            chosen_dictionaries=chosen_dictionaries,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TaskID",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_story_without_preload_content(
        self,
        file: Annotated[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]], Field(description="The text file (`.txt`) or Word document (`.docx`) that its contents will be used for creating a story.")],
        source_language: Annotated[Languages, Field(description="The language of the contents in the input file.")],
        title: Annotated[Optional[StrictStr], Field(description="The title of the story.")] = None,
        description: Annotated[Optional[StrictStr], Field(description="A brief description of the story.")] = None,
        narrator_voice_id: Annotated[Optional[StrictInt], Field(description="Specifies the identifier of the AI voice that will narrate the story. This voice selection determines the tone, accent, and delivery style used to bring the contents of the uploaded .txt or .docx file to life.")] = None,
        chosen_dictionaries: Annotated[Optional[Annotated[List[StrictInt], Field(min_length=1)]], Field(description="An optional list of dictionary IDs selected by the user. Each entry must be an integer corresponding to a valid dictionary ID. If provided, at least one ID is required.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Story


        :param file: The text file (`.txt`) or Word document (`.docx`) that its contents will be used for creating a story. (required)
        :type file: bytearray
        :param source_language: The language of the contents in the input file. (required)
        :type source_language: Languages
        :param title: The title of the story.
        :type title: str
        :param description: A brief description of the story.
        :type description: str
        :param narrator_voice_id: Specifies the identifier of the AI voice that will narrate the story. This voice selection determines the tone, accent, and delivery style used to bring the contents of the uploaded .txt or .docx file to life.
        :type narrator_voice_id: int
        :param chosen_dictionaries: An optional list of dictionary IDs selected by the user. Each entry must be an integer corresponding to a valid dictionary ID. If provided, at least one ID is required.
        :type chosen_dictionaries: List[int]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_story_serialize(
            file=file,
            source_language=source_language,
            title=title,
            description=description,
            narrator_voice_id=narrator_voice_id,
            chosen_dictionaries=chosen_dictionaries,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TaskID",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_story_serialize(
        self,
        file,
        source_language,
        title,
        description,
        narrator_voice_id,
        chosen_dictionaries,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'chosen_dictionaries': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if file is not None:
            _files['file'] = file
        if title is not None:
            _form_params.append(('title', title))
        if description is not None:
            _form_params.append(('description', description))
        if source_language is not None:
            _form_params.append(('source_language', source_language))
        if narrator_voice_id is not None:
            _form_params.append(('narrator_voice_id', narrator_voice_id))
        if chosen_dictionaries is not None:
            _form_params.append(('chosen_dictionaries', chosen_dictionaries))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/story',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def create_translated_story(
        self,
        run_id: StrictInt,
        create_translated_story_request_payload: CreateTranslatedStoryRequestPayload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TaskID:
        """Create Translated Story


        :param run_id: (required)
        :type run_id: int
        :param create_translated_story_request_payload: (required)
        :type create_translated_story_request_payload: CreateTranslatedStoryRequestPayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_translated_story_serialize(
            run_id=run_id,
            create_translated_story_request_payload=create_translated_story_request_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TaskID",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_translated_story_with_http_info(
        self,
        run_id: StrictInt,
        create_translated_story_request_payload: CreateTranslatedStoryRequestPayload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TaskID]:
        """Create Translated Story


        :param run_id: (required)
        :type run_id: int
        :param create_translated_story_request_payload: (required)
        :type create_translated_story_request_payload: CreateTranslatedStoryRequestPayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_translated_story_serialize(
            run_id=run_id,
            create_translated_story_request_payload=create_translated_story_request_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TaskID",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_translated_story_without_preload_content(
        self,
        run_id: StrictInt,
        create_translated_story_request_payload: CreateTranslatedStoryRequestPayload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Translated Story


        :param run_id: (required)
        :type run_id: int
        :param create_translated_story_request_payload: (required)
        :type create_translated_story_request_payload: CreateTranslatedStoryRequestPayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_translated_story_serialize(
            run_id=run_id,
            create_translated_story_request_payload=create_translated_story_request_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TaskID",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_translated_story_serialize(
        self,
        run_id,
        create_translated_story_request_payload,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if run_id is not None:
            _path_params['run_id'] = run_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_translated_story_request_payload is not None:
            _body_params = create_translated_story_request_payload


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/translated-story/{run_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_story_run_info_by_id(
        self,
        run_id: StrictInt,
        include_transcript: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> StoryRunInfoResponse:
        """Get Story Run Info


        :param run_id: (required)
        :type run_id: int
        :param include_transcript:
        :type include_transcript: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_story_run_info_by_id_serialize(
            run_id=run_id,
            include_transcript=include_transcript,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StoryRunInfoResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_story_run_info_by_id_with_http_info(
        self,
        run_id: StrictInt,
        include_transcript: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[StoryRunInfoResponse]:
        """Get Story Run Info


        :param run_id: (required)
        :type run_id: int
        :param include_transcript:
        :type include_transcript: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_story_run_info_by_id_serialize(
            run_id=run_id,
            include_transcript=include_transcript,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StoryRunInfoResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_story_run_info_by_id_without_preload_content(
        self,
        run_id: StrictInt,
        include_transcript: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Story Run Info


        :param run_id: (required)
        :type run_id: int
        :param include_transcript:
        :type include_transcript: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_story_run_info_by_id_serialize(
            run_id=run_id,
            include_transcript=include_transcript,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StoryRunInfoResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_story_run_info_by_id_serialize(
        self,
        run_id,
        include_transcript,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if run_id is not None:
            _path_params['run_id'] = run_id
        # process the query parameters
        if include_transcript is not None:
            
            _query_params.append(('include_transcript', include_transcript))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/story-result/{run_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_translated_story_run_info(
        self,
        run_id: StrictInt,
        target_language: Languages,
        include_transcript: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> StoryRunInfoResponse:
        """Get Translated Story Run Info


        :param run_id: (required)
        :type run_id: int
        :param target_language: (required)
        :type target_language: Languages
        :param include_transcript:
        :type include_transcript: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_translated_story_run_info_serialize(
            run_id=run_id,
            target_language=target_language,
            include_transcript=include_transcript,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StoryRunInfoResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_translated_story_run_info_with_http_info(
        self,
        run_id: StrictInt,
        target_language: Languages,
        include_transcript: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[StoryRunInfoResponse]:
        """Get Translated Story Run Info


        :param run_id: (required)
        :type run_id: int
        :param target_language: (required)
        :type target_language: Languages
        :param include_transcript:
        :type include_transcript: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_translated_story_run_info_serialize(
            run_id=run_id,
            target_language=target_language,
            include_transcript=include_transcript,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StoryRunInfoResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_translated_story_run_info_without_preload_content(
        self,
        run_id: StrictInt,
        target_language: Languages,
        include_transcript: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Translated Story Run Info


        :param run_id: (required)
        :type run_id: int
        :param target_language: (required)
        :type target_language: Languages
        :param include_transcript:
        :type include_transcript: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_translated_story_run_info_serialize(
            run_id=run_id,
            target_language=target_language,
            include_transcript=include_transcript,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StoryRunInfoResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_translated_story_run_info_serialize(
        self,
        run_id,
        target_language,
        include_transcript,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if run_id is not None:
            _path_params['run_id'] = run_id
        if target_language is not None:
            _path_params['target_language'] = target_language.value
        # process the query parameters
        if include_transcript is not None:
            
            _query_params.append(('include_transcript', include_transcript))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/translated-story-result/{run_id}/{target_language}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_translated_story_status_by_id(
        self,
        task_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> OrchestratorPipelineResult:
        """Get Translated Story Status


        :param task_id: (required)
        :type task_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_translated_story_status_by_id_serialize(
            task_id=task_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrchestratorPipelineResult",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_translated_story_status_by_id_with_http_info(
        self,
        task_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[OrchestratorPipelineResult]:
        """Get Translated Story Status


        :param task_id: (required)
        :type task_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_translated_story_status_by_id_serialize(
            task_id=task_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrchestratorPipelineResult",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_translated_story_status_by_id_without_preload_content(
        self,
        task_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Translated Story Status


        :param task_id: (required)
        :type task_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_translated_story_status_by_id_serialize(
            task_id=task_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrchestratorPipelineResult",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_translated_story_status_by_id_serialize(
        self,
        task_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if task_id is not None:
            _path_params['task_id'] = task_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/translated-story/{task_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cambai.api.text_to_audio_api import TextToAudioApi


class TestTextToAudioApi(unittest.TestCase):
    """TextToAudioApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TextToAudioApi()

    def tearDown(self) -> None:
        pass

    def test_create_text_to_sound(self) -> None:
        """Test case for create_text_to_sound

        Create Text to Sound
        """
        pass

    def test_get_text_to_audio_status_by_id(self) -> None:
        """Test case for get_text_to_audio_status_by_id

        Get Text To Audio Status
        """
        pass

    def test_get_text_to_sound_run_result_by_id(self) -> None:
        """Test case for get_text_to_sound_run_result_by_id

        Get Text to Sound Run Result
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cambai.api.text_to_voice_api import TextToVoiceApi


class TestTextToVoiceApi(unittest.TestCase):
    """TextToVoiceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TextToVoiceApi()

    def tearDown(self) -> None:
        pass

    def test_create_voice_from_description(self) -> None:
        """Test case for create_voice_from_description

        Create Voice from Description
        """
        pass

    def test_get_text_to_voice_run_result_by_id(self) -> None:
        """Test case for get_text_to_voice_run_result_by_id

        Get Text-to-Voice Run Result
        """
        pass

    def test_text_to_voice_task_id_get(self) -> None:
        """Test case for text_to_voice_task_id_get

        Get Text-to-Voice Task Status
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cambai.api.stories_api import StoriesApi


class TestStoriesApi(unittest.TestCase):
    """StoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StoriesApi()

    def tearDown(self) -> None:
        pass

    def test_create_story(self) -> None:
        """Test case for create_story

        Create Story
        """
        pass

    def test_create_translated_story(self) -> None:
        """Test case for create_translated_story

        Create Translated Story
        """
        pass

    def test_get_story_run_info_by_id(self) -> None:
        """Test case for get_story_run_info_by_id

        Get Story Run Info
        """
        pass

    def test_get_translated_story_run_info(self) -> None:
        """Test case for get_translated_story_run_info

        Get Translated Story Run Info
        """
        pass

    def test_get_translated_story_status_by_id(self) -> None:
        """Test case for get_translated_story_status_by_id

        Get Translated Story Status
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cambai.api.audio_separation_api import AudioSeparationApi


class TestAudioSeparationApi(unittest.TestCase):
    """AudioSeparationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AudioSeparationApi()

    def tearDown(self) -> None:
        pass

    def test_create_audio_separation(self) -> None:
        """Test case for create_audio_separation

        Create Audio Separation
        """
        pass

    def test_get_audio_separation_run_info_by_id(self) -> None:
        """Test case for get_audio_separation_run_info_by_id

        Get Audio Separation Run Info
        """
        pass

    def test_get_audio_separation_status_by_id(self) -> None:
        """Test case for get_audio_separation_status_by_id

        Get Audio Separation Status
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TextToVoiceRunInfoResponse(BaseModel):
    """
    TextToVoiceRunInfoResponse
    """ # noqa: E501
    previews: Optional[List[StrictStr]] = Field(default=None, description="An array of three distinct URL strings, each pointing to a unique voice sample generated from your text prompt. These samples represent different voice interpretations based on your description, allowing you to compare options before selecting your preferred voice for further use. ")
    __properties: ClassVar[List[str]] = ["previews"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TextToVoiceRunInfoResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TextToVoiceRunInfoResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "previews": obj.get("previews")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from cambai.models.audio_output_file_url_response import AudioOutputFileURLResponse
from cambai.models.audio_output_type import AudioOutputType
from cambai.models.audio_separation_run_info_response import AudioSeparationRunInfoResponse
from cambai.models.body_translate_translate_post import BodyTranslateTranslatePost
from cambai.models.create_api_key_request_payload import CreateAPIKeyRequestPayload
from cambai.models.create_custom_voice_out import CreateCustomVoiceOut
from cambai.models.create_tts_request_payload import CreateTTSRequestPayload
# from cambai.models.create_tts_stream_request_payload import CreateTTSStreamRequestPayload
from cambai.models.create_text_to_audio_request_payload import CreateTextToAudioRequestPayload
from cambai.models.create_text_to_voice_request_payload import CreateTextToVoiceRequestPayload
from cambai.models.create_translated_story_request_payload import CreateTranslatedStoryRequestPayload
from cambai.models.create_translated_tts_request_payload import CreateTranslatedTTSRequestPayload
from cambai.models.create_translation_stream_request_payload import CreateTranslationStreamRequestPayload
from cambai.models.dialogue_item import DialogueItem
from cambai.models.dictionary import Dictionary
from cambai.models.dub_alt_format_response_body import DubAltFormatResponseBody
from cambai.models.dubbed_output_in_alt_format_request_payload import DubbedOutputInAltFormatRequestPayload
from cambai.models.end_to_end_dubbing_request_payload import EndToEndDubbingRequestPayload
from cambai.models.expire_api_key_request_payload import ExpireAPIKeyRequestPayload
from cambai.models.formalities import Formalities
from cambai.models.gender import Gender
from cambai.models.http_validation_error import HTTPValidationError
from cambai.models.language_item import LanguageItem
from cambai.models.languages import Languages
from cambai.models.orchestrator_pipeline_result import OrchestratorPipelineResult
from cambai.models.output_api_key import OutputAPIKey
from cambai.models.output_format import OutputFormat
from cambai.models.output_type import OutputType
from cambai.models.request_dubbed_output_in_alt_format200_response import RequestDubbedOutputInAltFormat200Response
from cambai.models.run_info_response import RunInfoResponse
from cambai.models.story_run_info_response import StoryRunInfoResponse
from cambai.models.tts_stream_output_format import TTSStreamOutputFormat
from cambai.models.task_id import TaskID
from cambai.models.task_status import TaskStatus
from cambai.models.text_to_voice_run_info_response import TextToVoiceRunInfoResponse
from cambai.models.transcript_data_type import TranscriptDataType
from cambai.models.transcript_file_format import TranscriptFileFormat
from cambai.models.translation_result import TranslationResult
from cambai.models.validation_error import ValidationError
from cambai.models.validation_error_loc_inner import ValidationErrorLocInner
from cambai.models.video_output_type_without_avi import VideoOutputTypeWithoutAVI
from cambai.models.voice_item import VoiceItem



# flake8: noqa

# import apis into api package
from cambai.api.apis_api import CambAI
from cambai.api.audio_separation_api import AudioSeparationApi
from cambai.api.dictionaries_api import DictionariesApi
from cambai.api.dub_api import DubApi
from cambai.api.stories_api import StoriesApi
from cambai.api.text_to_audio_api import TextToAudioApi
from cambai.api.text_to_speech_api import TextToSpeechApi
from cambai.api.text_to_voice_api import TextToVoiceApi




# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cambai.models.formalities import Formalities
from cambai.models.gender import Gender
from cambai.models.languages import Languages
from typing import Optional, Set
from typing_extensions import Self

class CreateTranslationStreamRequestPayload(BaseModel):
    """
    CreateTranslationStreamRequestPayload
    """ # noqa: E501
    text: StrictStr
    source_language: Languages
    target_language: Languages
    formality: Optional[Formalities] = None
    gender: Optional[Gender] = None
    __properties: ClassVar[List[str]] = ["text", "source_language", "target_language", "formality", "gender"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateTranslationStreamRequestPayload from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if formality (nullable) is None
        # and model_fields_set contains the field
        if self.formality is None and "formality" in self.model_fields_set:
            _dict['formality'] = None

        # set to None if gender (nullable) is None
        # and model_fields_set contains the field
        if self.gender is None and "gender" in self.model_fields_set:
            _dict['gender'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateTranslationStreamRequestPayload from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "text": obj.get("text"),
            "source_language": obj.get("source_language"),
            "target_language": obj.get("target_language"),
            "formality": obj.get("formality"),
            "gender": obj.get("gender")
        })
        return _obj





# # coding: utf-8

# """
#     FastAPI

#     No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

#     The version of the OpenAPI document: 0.1.0
#     Generated by OpenAPI Generator (https://openapi-generator.tech)

#     Do not edit the class manually.
# """  # noqa: E501


# import unittest

# from cambai.models.create_tts_stream_request_payload import CreateTTSStreamRequestPayload

# class TestCreateTTSStreamRequestPayload(unittest.TestCase):
#     """CreateTTSStreamRequestPayload unit test stubs"""

#     def setUp(self):
#         pass

#     def tearDown(self):
#         pass

#     def make_instance(self, include_optional) -> CreateTTSStreamRequestPayload:
#         """Test CreateTTSStreamRequestPayload
#             include_optional is a boolean, when False only required
#             params are included, when True both required and
#             optional params are included """
#         # uncomment below to create an instance of `CreateTTSStreamRequestPayload`
#         """
#         model = CreateTTSStreamRequestPayload()
#         if include_optional:
#             return CreateTTSStreamRequestPayload(
#                 text = '',
#                 voice_id = 56,
#                 language = 1,
#                 gender = 0,
#                 age = 56,
#                 output_format = 'wav'
#             )
#         else:
#             return CreateTTSStreamRequestPayload(
#                 text = '',
#                 voice_id = 56,
#                 language = 1,
#         )
#         """

#     def testCreateTTSStreamRequestPayload(self):
#         """Test CreateTTSStreamRequestPayload"""
#         # inst_req_only = self.make_instance(include_optional=False)
#         # inst_req_and_optional = self.make_instance(include_optional=True)

# if __name__ == '__main__':
#     unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cambai.api.dub_api import DubApi


class TestDubApi(unittest.TestCase):
    """DubApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DubApi()

    def tearDown(self) -> None:
        pass

    def test_get_dubbed_output_in_alt_format_status_by_id(self) -> None:
        """Test case for get_dubbed_output_in_alt_format_status_by_id

        Get Dubbed Output in Alt Format Status
        """
        pass

    def test_get_dubbed_run_transcript(self) -> None:
        """Test case for get_dubbed_run_transcript

        Get Dubbed Run Transcript
        """
        pass

    def test_request_dubbed_output_in_alt_format(self) -> None:
        """Test case for request_dubbed_output_in_alt_format

        Get Dubbed Output in Alt Format
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from cambai.models.languages import Languages
from typing import Optional, Set
from typing_extensions import Self

class EndToEndDubbingRequestPayload(BaseModel):
    """
    EndToEndDubbingRequestPayload
    """ # noqa: E501
    video_url: StrictStr = Field(description="The URL of the media file to be used to create the end-to-end dubbing task.")
    source_language: Languages = Field(description="The original language of the media file to be used to create the end-to-end dubbing task.")
    target_languages: Optional[List[Languages]] = Field(default=None, description="The list of desired languages that the media file will be dubbed to.")
    selected_audio_tracks: Optional[Annotated[List[Optional[StrictInt]], Field(min_length=1, max_length=2)]] = Field(default=None, description="Optional array of one or two zero‑based audio track indices to dub. Only supported for `MXF` files. If omitted, the first audio track (index 0) is used by default.")
    add_output_as_an_audio_track: Optional[StrictBool] = Field(default=None, description="Optional flag to append the dubbed audio as a new audio track in the output file. Only supported for `MXF` files. If `true`, the dubbed audio is added as an additional track; if `false` or omitted, the source would be returned with only dubbed audio.")
    chosen_dictionaries: Optional[Annotated[List[StrictInt], Field(min_length=1)]] = Field(default=None, description="An optional list of dictionary IDs selected by the user. Each entry must be an integer corresponding to a valid dictionary ID. If provided, at least one ID is required.")
    __properties: ClassVar[List[str]] = ["video_url", "source_language", "target_languages", "selected_audio_tracks", "add_output_as_an_audio_track", "chosen_dictionaries"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EndToEndDubbingRequestPayload from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EndToEndDubbingRequestPayload from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "video_url": obj.get("video_url"),
            "source_language": obj.get("source_language"),
            "target_languages": obj.get("target_languages"),
            "selected_audio_tracks": obj.get("selected_audio_tracks"),
            "add_output_as_an_audio_track": obj.get("add_output_as_an_audio_track"),
            "chosen_dictionaries": obj.get("chosen_dictionaries")
        })
        return _obj





# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from cambai.models.run_info_response import RunInfoResponse

class TestRunInfoResponse(unittest.TestCase):
    """RunInfoResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RunInfoResponse:
        """Test RunInfoResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RunInfoResponse`
        """
        model = RunInfoResponse()
        if include_optional:
            return RunInfoResponse(
                run_id = 56,
                output_video_url = '',
                output_audio_url = '',
                transcript = [
                    cambai.models.dialogue_item.DialogueItem(
                        start = 1.337, 
                        end = 1.337, 
                        text = '', 
                        speaker = '', )
                    ]
            )
        else:
            return RunInfoResponse(
        )
        """

    def testRunInfoResponse(self):
        """Test RunInfoResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from cambai.models.dubbed_output_in_alt_format_request_payload import DubbedOutputInAltFormatRequestPayload
from cambai.models.languages import Languages
from cambai.models.request_dubbed_output_in_alt_format200_response import RequestDubbedOutputInAltFormat200Response
from cambai.models.task_status import TaskStatus
from cambai.models.transcript_data_type import TranscriptDataType
from cambai.models.transcript_file_format import TranscriptFileFormat

from cambai.api_client import ApiClient, RequestSerialized
from cambai.api_response import ApiResponse
from cambai.rest import RESTResponseType


class DubApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_dubbed_output_in_alt_format_status_by_id(
        self,
        task_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TaskStatus:
        """Get Dubbed Output in Alt Format Status


        :param task_id: (required)
        :type task_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_dubbed_output_in_alt_format_status_by_id_serialize(
            task_id=task_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TaskStatus",
            '422': "ValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_dubbed_output_in_alt_format_status_by_id_with_http_info(
        self,
        task_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TaskStatus]:
        """Get Dubbed Output in Alt Format Status


        :param task_id: (required)
        :type task_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_dubbed_output_in_alt_format_status_by_id_serialize(
            task_id=task_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TaskStatus",
            '422': "ValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_dubbed_output_in_alt_format_status_by_id_without_preload_content(
        self,
        task_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Dubbed Output in Alt Format Status


        :param task_id: (required)
        :type task_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_dubbed_output_in_alt_format_status_by_id_serialize(
            task_id=task_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TaskStatus",
            '422': "ValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_dubbed_output_in_alt_format_status_by_id_serialize(
        self,
        task_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if task_id is not None:
            _path_params['task_id'] = task_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/dub-alt-format/{task_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_dubbed_run_transcript(
        self,
        run_id: StrictInt,
        language: Languages,
        format_type: Annotated[Optional[TranscriptFileFormat], Field(description="The format to use for the transcription output. Either `srt`, `vtt` or `txt`. Defaults to `txt`.")] = None,
        data_type: Annotated[Optional[TranscriptDataType], Field(description="The data type for the transcription being returned. Returns the raw data of the transcription or a presigned url for the file that contains the transcript contents in the specified format.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Get Dubbed Run Transcript


        :param run_id: (required)
        :type run_id: int
        :param language: (required)
        :type language: Languages
        :param format_type: The format to use for the transcription output. Either `srt`, `vtt` or `txt`. Defaults to `txt`.
        :type format_type: TranscriptFileFormat
        :param data_type: The data type for the transcription being returned. Returns the raw data of the transcription or a presigned url for the file that contains the transcript contents in the specified format.
        :type data_type: TranscriptDataType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_dubbed_run_transcript_serialize(
            run_id=run_id,
            language=language,
            format_type=format_type,
            data_type=data_type,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_dubbed_run_transcript_with_http_info(
        self,
        run_id: StrictInt,
        language: Languages,
        format_type: Annotated[Optional[TranscriptFileFormat], Field(description="The format to use for the transcription output. Either `srt`, `vtt` or `txt`. Defaults to `txt`.")] = None,
        data_type: Annotated[Optional[TranscriptDataType], Field(description="The data type for the transcription being returned. Returns the raw data of the transcription or a presigned url for the file that contains the transcript contents in the specified format.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Get Dubbed Run Transcript


        :param run_id: (required)
        :type run_id: int
        :param language: (required)
        :type language: Languages
        :param format_type: The format to use for the transcription output. Either `srt`, `vtt` or `txt`. Defaults to `txt`.
        :type format_type: TranscriptFileFormat
        :param data_type: The data type for the transcription being returned. Returns the raw data of the transcription or a presigned url for the file that contains the transcript contents in the specified format.
        :type data_type: TranscriptDataType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_dubbed_run_transcript_serialize(
            run_id=run_id,
            language=language,
            format_type=format_type,
            data_type=data_type,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_dubbed_run_transcript_without_preload_content(
        self,
        run_id: StrictInt,
        language: Languages,
        format_type: Annotated[Optional[TranscriptFileFormat], Field(description="The format to use for the transcription output. Either `srt`, `vtt` or `txt`. Defaults to `txt`.")] = None,
        data_type: Annotated[Optional[TranscriptDataType], Field(description="The data type for the transcription being returned. Returns the raw data of the transcription or a presigned url for the file that contains the transcript contents in the specified format.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Dubbed Run Transcript


        :param run_id: (required)
        :type run_id: int
        :param language: (required)
        :type language: Languages
        :param format_type: The format to use for the transcription output. Either `srt`, `vtt` or `txt`. Defaults to `txt`.
        :type format_type: TranscriptFileFormat
        :param data_type: The data type for the transcription being returned. Returns the raw data of the transcription or a presigned url for the file that contains the transcript contents in the specified format.
        :type data_type: TranscriptDataType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_dubbed_run_transcript_serialize(
            run_id=run_id,
            language=language,
            format_type=format_type,
            data_type=data_type,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_dubbed_run_transcript_serialize(
        self,
        run_id,
        language,
        format_type,
        data_type,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if run_id is not None:
            _path_params['run_id'] = run_id
        if language is not None:
            _path_params['language'] = language.value
        # process the query parameters
        if format_type is not None:
            
            _query_params.append(('format_type', format_type.value))
            
        if data_type is not None:
            
            _query_params.append(('data_type', data_type.value))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/transcript/{run_id}/{language}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def request_dubbed_output_in_alt_format(
        self,
        run_id: StrictInt,
        language: Languages,
        dubbed_output_in_alt_format_request_payload: DubbedOutputInAltFormatRequestPayload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RequestDubbedOutputInAltFormat200Response:
        """Get Dubbed Output in Alt Format


        :param run_id: (required)
        :type run_id: int
        :param language: (required)
        :type language: Languages
        :param dubbed_output_in_alt_format_request_payload: (required)
        :type dubbed_output_in_alt_format_request_payload: DubbedOutputInAltFormatRequestPayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._request_dubbed_output_in_alt_format_serialize(
            run_id=run_id,
            language=language,
            dubbed_output_in_alt_format_request_payload=dubbed_output_in_alt_format_request_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RequestDubbedOutputInAltFormat200Response",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def request_dubbed_output_in_alt_format_with_http_info(
        self,
        run_id: StrictInt,
        language: Languages,
        dubbed_output_in_alt_format_request_payload: DubbedOutputInAltFormatRequestPayload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RequestDubbedOutputInAltFormat200Response]:
        """Get Dubbed Output in Alt Format


        :param run_id: (required)
        :type run_id: int
        :param language: (required)
        :type language: Languages
        :param dubbed_output_in_alt_format_request_payload: (required)
        :type dubbed_output_in_alt_format_request_payload: DubbedOutputInAltFormatRequestPayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._request_dubbed_output_in_alt_format_serialize(
            run_id=run_id,
            language=language,
            dubbed_output_in_alt_format_request_payload=dubbed_output_in_alt_format_request_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RequestDubbedOutputInAltFormat200Response",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def request_dubbed_output_in_alt_format_without_preload_content(
        self,
        run_id: StrictInt,
        language: Languages,
        dubbed_output_in_alt_format_request_payload: DubbedOutputInAltFormatRequestPayload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Dubbed Output in Alt Format


        :param run_id: (required)
        :type run_id: int
        :param language: (required)
        :type language: Languages
        :param dubbed_output_in_alt_format_request_payload: (required)
        :type dubbed_output_in_alt_format_request_payload: DubbedOutputInAltFormatRequestPayload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._request_dubbed_output_in_alt_format_serialize(
            run_id=run_id,
            language=language,
            dubbed_output_in_alt_format_request_payload=dubbed_output_in_alt_format_request_payload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RequestDubbedOutputInAltFormat200Response",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _request_dubbed_output_in_alt_format_serialize(
        self,
        run_id,
        language,
        dubbed_output_in_alt_format_request_payload,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if run_id is not None:
            _path_params['run_id'] = run_id
        if language is not None:
            _path_params['language'] = language.value
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if dubbed_output_in_alt_format_request_payload is not None:
            _body_params = dubbed_output_in_alt_format_request_payload


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/dub-alt-format/{run_id}/{language}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Any, List, Optional
from cambai.models.dub_alt_format_response_body import DubAltFormatResponseBody
from cambai.models.task_id import TaskID
from pydantic import StrictStr, Field
from typing import Union, List, Set, Optional, Dict
from typing_extensions import Literal, Self

REQUESTDUBBEDOUTPUTINALTFORMAT200RESPONSE_ONE_OF_SCHEMAS = ["DubAltFormatResponseBody", "TaskID"]

class RequestDubbedOutputInAltFormat200Response(BaseModel):
    """
    RequestDubbedOutputInAltFormat200Response
    """
    # data type: DubAltFormatResponseBody
    oneof_schema_1_validator: Optional[DubAltFormatResponseBody] = Field(default=None, description="A JSON that contains the presigned url of the output file.")
    # data type: TaskID
    oneof_schema_2_validator: Optional[TaskID] = Field(default=None, description="A JSON that contains the unique identifier for the task. This is used to query the status of the exporting dubbed output to alt format task that is running. It is returned when a create request is made for fetching the dubbed output in an alt file format, in case it does not exist.")
    actual_instance: Optional[Union[DubAltFormatResponseBody, TaskID]] = None
    one_of_schemas: Set[str] = { "DubAltFormatResponseBody", "TaskID" }

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )


    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = RequestDubbedOutputInAltFormat200Response.model_construct()
        error_messages = []
        match = 0
        # validate data type: DubAltFormatResponseBody
        if not isinstance(v, DubAltFormatResponseBody):
            error_messages.append(f"Error! Input type `{type(v)}` is not `DubAltFormatResponseBody`")
        else:
            match += 1
        # validate data type: TaskID
        if not isinstance(v, TaskID):
            error_messages.append(f"Error! Input type `{type(v)}` is not `TaskID`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in RequestDubbedOutputInAltFormat200Response with oneOf schemas: DubAltFormatResponseBody, TaskID. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in RequestDubbedOutputInAltFormat200Response with oneOf schemas: DubAltFormatResponseBody, TaskID. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Union[str, Dict[str, Any]]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into DubAltFormatResponseBody
        try:
            instance.actual_instance = DubAltFormatResponseBody.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into TaskID
        try:
            instance.actual_instance = TaskID.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into RequestDubbedOutputInAltFormat200Response with oneOf schemas: DubAltFormatResponseBody, TaskID. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into RequestDubbedOutputInAltFormat200Response with oneOf schemas: DubAltFormatResponseBody, TaskID. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], DubAltFormatResponseBody, TaskID]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# # coding: utf-8

# """
#     FastAPI

#     No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

#     The version of the OpenAPI document: 0.1.0
#     Generated by OpenAPI Generator (https://openapi-generator.tech)

#     Do not edit the class manually.
# """  # noqa: E501


# import unittest

# from cambai.models.tts_stream_output_format import TTSStreamOutputFormat

# class TestTTSStreamOutputFormat(unittest.TestCase):
#     """TTSStreamOutputFormat unit test stubs"""

#     def setUp(self):
#         pass

#     def tearDown(self):
#         pass

#     def testTTSStreamOutputFormat(self):
#         """Test TTSStreamOutputFormat"""
#         # inst = TTSStreamOutputFormat()

# if __name__ == '__main__':
#     unittest.main()
